<?php

/* skel.class.php - base skeleton class
   EVERY class of your application should extend it
   so you should put all your commonly used code here */
   
class Skel {
    var $datalink;
    var $err_msg;
    var $table;
    var $pkey;
    var $fields = array();
    
    /**
     * @return boolean
     * @param int $id = null
     * @desc Constructor. Initializes the Database connection.
    */
    function Skel() {
        global $datalink;
        $this->datalink = $datalink;
        $this->init();
    }
    
    /**
     * @return void
     * @desc Skeleton initialization function.
    */
    /* This is just a skeleton to make sure the app doesn't crash
           but all your child classes should override it */
    function init() { ; }
        
    
    /**
     * @return boolean
     * @param int $id = null
     * @desc Filters the input received by POST and calls __commit if it is appropriate
    */
    function check_input($id = null) {
        # Iterate through the object's fields
        foreach($this->fields as $field) {
            # Make sure they are all filled
            if (!isset($_POST[$field])) {
                # Otherwise, report every error
                $this->error_messages .= "The value for the field <b>" .
                $field . "</b> is missing.<br>";
            } else {
                # Clean up every field against SQL injections
                $this->$field = mysql_escape_string($_POST[$field]);
            }
        }
        
        # If errors have been reported, return FALSE
        if (!empty($this->error_messages)) {
            return FALSE;
        } else {
            # Otherwise, return whatever __commit returns
            return $this->__commit($id);
        }
    }
    
    
    /**
     * @return boolean
     * @param int $id
     * @desc Fills out instance variables from database
    */
    function __commit($id = null) {
        # If we're not working on an existing record
        if (empty($id)) {
            # Create a new one
            return $this->__insert();
        } else {
            # Otherwise, update our current record.
            return $this->__update();
        }
    }
    
    /**
     * @return string
     * @desc Returns a comma-separated list of fields
    */
    function __get_fields() {
        # Initialize an empty string
        $sequence = "";
        # Add a list of fields, comma separated
        foreach($this->fields as $field) {
            $sequence .= $field . ", ";
        }
        # then truncate the result and return
        $size = strlen($sequence)-2;
        return substr($sequence, 0, $size);
    }
    
    /**
     * @return string
     * @desc Returns a comma-separated list of values
    */
    function __get_values() {
        # Initialize the string
        $sequence = "";
        # Create a list of values
        foreach($this->fields as $field) {
            $sequence .= "'".$this->$field . "', ";
        }
        # Truncate and return
        $size = strlen($sequence)-2;
        return substr($sequence, 0, $size);
    }
    
    // Skeleton functions. Those need to be overloaded
    function __insert() { ; }
    function __update() { ; }
}