<?php


/**
 * @return string
 * @param pointer $index_content
 * @desc Executes the appropriate module function based on GET parameters.
*/
function user(&$index_content) {
        # This is our list of allowed functions
        $functions = array("pop", "form_create_user", "process", "list_accounts", "delete_user"); // you can easily add delete, list_all, search, etc...
        # Return to the main screen upon error
        if (!in_array($_GET['action'], $functions)) {
                require_once("home.php"); // You should implement real error control here
                return home($index_content);
        } else {
                # Otherwise, return the result of the function
                return $_GET['action']($index_content);
        }
}

/**
 * @return string
 * @param pointer $index_content
 * @desc Displays user account details
*/
function pop(&$index_content) { // Note the &, we have passed $index_content by reference so we can modify it
    # Prepare to instanciate a user object
    require_class("user");
    # Initialize the templating engine
    $parser =& new HTML_Template_Sigma(TPL_PATH, TPL_CACHE_PATH);
    $parser->loadTemplateFile("user_details.tpl", TRUE, TRUE);
    
    # Create user object instance
    $user =& new User();
    
    # Grab the integer value of GET[id]
    $id = intval($_GET['id']);
    # Perform the method pop() on User. On error, display error message
    if (!$user->pop($id)) { // Obviously, this is just an example...
        $index_content .= err("The user #$id does not exist in this database");
        $index_content .= err($user->err_msg);
        return "Error";
    }
   
    # Synchronize the user object and the template    
    foreach(array_keys(get_object_vars($user)) as $current) {
        $parser->setVariable($current, $user->$current);
    }
    
    # Add our new content to $index_content
    $index_content .= $parser->get();
    # Return current title to switchboard()
    return "User details";
}

/**
 * @return string
 * @param pointer $index_content
 * @desc Displays user creation form
*/
function form_create_user(&$index_content) {
    
    # Initialize the templating engine
    $parser =& new HTML_Template_Sigma(TPL_PATH, TPL_CACHE_PATH);
    $parser->loadTemplateFile("form_new_user.tpl", TRUE, TRUE);
    
    # Output the form to index_content
    $index_content .= $parser->get();
    return "Create a new User";
}

/**
 * @return string
 * @param pointer $index_content
 * @desc Creates a new account based on POST content
*/
function process(&$index_content) {
    require_class("user");
    # Instanciates user object
    $user =& new User();
    # Perform the input filtering and assignment
    if (!$user->check_input()) {
        # Error handling block
        $index_content .= err($user->error_messages);
        return "Error";
    } else {
        # Success message, then redirect output to list_accounts function
        $index_content .= succ("User account created");
        return list_accounts($index_content);
    }
}

/**
 * @return string
 * @param pointer $index_content
 * @desc Displays a list of all user accounts
*/
function list_accounts(&$index_content) {
    # This makes our database connection accessible to this function
    global $datalink;
    # This will select all the accounts
    $query = "SELECT a.id, a.first_name, a.last_name, a.email FROM `users` a ORDER BY id DESC LIMIT 50";
    
    # Initialize the templating engine
    $parser =& new HTML_Template_Sigma(TPL_PATH, TPL_CACHE_PATH);
    $parser->loadTemplateFile("list_users.tpl", TRUE, TRUE);
    
    # Perform the query and error handling
    if ($datalink->isError($result = $datalink->query($query))) {
        $index_content .= err("Unable to list accounts.<br>" . DB::ErrorMessage($result));
        return "Error";
    } else {
        # $result->numRows() returns the number of results from the query
       if ($result->numRows() > 0) {
           # Fetch each result in an associative array called $user
           while ($result->fetchInto($user, DB_FETCHMODE_ASSOC)) {
               # Then use these values to parse the template block
               $parser->setVariable("first_name", $user['first_name']);
               $parser->setVariable("last_name", $user['last_name']);
               $parser->setVariable("id", $user['id']);
               $parser->setVariable("email", $user['email']);
               
               # This parses a template block (see list_users.tpl)
               $parser->parse("user_block");
               
           }
           # Append output to index_content
           $index_content .= $parser->get();
       } else {
           # Handle empty table
           $index_content .= "There are currently no user accounts";
       }
    }
    
    return "Accounts List";
}

/**
 * @return string
 * @param pointer $index_content
 * @desc Displays user account details
*/
function delete_user(&$index_content) {
    # This function uses the database
    global $datalink;
    
    # Handle invalid ID parameter
    if (!isset($_GET['user_id'])) {
        $index_content .= err("You must specify a user ID");
        return "Error";
    } else {
        # Assign ID to the integer value of GET[user_id]
        $id = intval($_GET['user_id']);
    }
    
    # Prepare your query
    $query = "DELETE FROM `users` WHERE id = '$id'";
    # (This could have been done through DB's prepare/execute methods)
    
    # Perform the query on the table and perform error handling
    if ($datalink->isError($result = $datalink->query($query))) {
        $index_content .= err("Unable to delete the specified account.<br>" . DB::ErrorMessage($result));
        return "Error";
    } else {
        $query = "ALTER TABLE `users` AUTO_INCREMENT = 1";
        # The following query will reset the counter if the table is empty.
        $datalink->query($query); // It is not a big deal if this query fails.
        $index_content .= succ("User account $id has been deleted<br>");
        # Take the user back to the accounts listing
        return list_accounts($index_content);
    }
}

?>